/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Load Generator : cpp-python interface
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: load_generator.h,v 1.2 2008/03/31 13:58:53 ptedesco Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_LOAD_GENERATOR_LOAD_GENERATION_H_
#define GLITE_DATA_TRANSFER_LOAD_GENERATOR_LOAD_GENERATION_H_

#include <string>
#include <vector>
#include <boost/shared_ptr.hpp>

namespace glite {
namespace data {
namespace transfer {
namespace load_generator {

/**
 * FileData
 * couple source-destination SURL for transfer submissions (to be returned by
 * python script)
 */
class FileData{
public:
    /**
     * source file SURL
     */
    std::string sourceFile;
    /**
     * destination file SURL
     */
    std::string destinationFile;
};

/**
 * EndpointData
 * data about an endpoint (to be passed to pyton script)
 */
class EndpointData{
public:
    /**
     * the endpoint path
     */
    std::string path;
    /**
     * the file name pattern
     */
    std::string pattern;
};

/**
 * array of FileData objects
 */
typedef std::vector<boost::shared_ptr<FileData> > FileDataArray;

} // namespace load_generator
} // namespace transfer
} // namespace data
} // namespace glite

#endif // GLITE_DATA_TRANSFER_LOAD_GENERATOR_LOAD_GENERATION_H_


